@@ -49,9 +49,8 @@ class ElasticBlockStore(EC2BaseResponse):
         return template.render(snapshot=snapshot)
 
     def create_snapshots(self) -> str:
-        params = self._get_params()
-        instance_spec = params.get("InstanceSpecification")
-        description = params.get("Description", "")
+        instance_spec = self._get_param("InstanceSpecification", {})
+        description = self._get_param("Description", "")
         tags = self._parse_tag_specification()
         snapshot_tags = tags.get("snapshot", {})
 
@@ -70,7 +69,7 @@ class ElasticBlockStore(EC2BaseResponse):
         volume_type = self._get_param("VolumeType")
         tags = self._parse_tag_specification()
         volume_tags = tags.get("volume", {})
-        encrypted = self._get_bool_param("Encrypted", if_none=False)
+        encrypted = self._get_bool_param("Encrypted", False)
         kms_key_id = self._get_param("KmsKeyId")
         iops = self._get_param("Iops")
         throughput = self._get_param("Throughput")
@@ -116,7 +115,7 @@ class ElasticBlockStore(EC2BaseResponse):
 
     def describe_volumes_modifications(self) -> str:
         filters = self._filters_from_querystring()
-        volume_ids = self._get_multi_param("VolumeId")
+        volume_ids = self._get_param("VolumeIds", [])
         modifications = self.ec2_backend.describe_volumes_modifications(
             volume_ids=volume_ids, filters=filters
         )
@@ -141,7 +140,7 @@ class ElasticBlockStore(EC2BaseResponse):
 
     def describe_snapshots(self) -> str:
         filters = self._filters_from_querystring()
-        snapshot_ids = self._get_multi_param("SnapshotId")
+        snapshot_ids = self._get_param("SnapshotIds", [])
         snapshots = self.ec2_backend.describe_snapshots(
             snapshot_ids=snapshot_ids, filters=filters
         )
@@ -150,7 +149,7 @@ class ElasticBlockStore(EC2BaseResponse):
 
     def describe_volumes(self) -> str:
         filters = self._filters_from_querystring()
-        volume_ids = self._get_multi_param("VolumeId")
+        volume_ids = self._get_param("VolumeIds", [])
         volumes = self.ec2_backend.describe_volumes(
             volume_ids=volume_ids, filters=filters
         )
@@ -202,8 +201,8 @@ class ElasticBlockStore(EC2BaseResponse):
     def modify_snapshot_attribute(self) -> ActionResult:
         snapshot_id = self._get_param("SnapshotId")
         operation_type = self._get_param("OperationType")
-        groups = self._get_multi_param("UserGroup")
-        user_ids = self._get_multi_param("UserId")
+        groups = self._get_param("GroupNames", [])
+        user_ids = self._get_param("UserIds", [])
 
         self.error_on_dryrun()
 
@@ -275,7 +274,7 @@ CREATE_VOLUME_RESPONSE = """<CreateVolumeResponse xmlns="http://ec2.amazonaws.co
     <throughput>{{ volume.throughput }}</throughput>
   {% endif %}
   {% if volume.multi_attach_enabled %}
-    <multiAttachEnabled>{{ volume.multi_attach_enabled }}</multiAttachEnabled>
+    <multiAttachEnabled>{{ volume.multi_attach_enabled|lower }}</multiAttachEnabled>
   {% endif %}
 </CreateVolumeResponse>"""
 
@@ -330,7 +329,7 @@ DESCRIBE_VOLUMES_RESPONSE = """<DescribeVolumesResponse xmlns="http://ec2.amazon
                <throughput>{{ volume.throughput }}</throughput>
              {% endif %}
              {% if volume.multi_attach_enabled %}
-               <multiAttachEnabled>{{ volume.multi_attach_enabled }}</multiAttachEnabled>
+               <multiAttachEnabled>{{ volume.multi_attach_enabled|lower }}</multiAttachEnabled>
              {% endif %}
           </item>
       {% endfor %}
@@ -493,7 +492,7 @@ MODIFY_VOLUME_RESPONSE = """<?xml version="1.0" encoding="UTF-8"?>
             <originalThroughput>{{ volume_modification.original_throughput }}</originalThroughput>
         {% endif %}
         {% if volume_modification.original_multi_attach_enabled is not none %}
-            <originalMultiAttachEnabled>{{ volume_modification.original_multi_attach_enabled }}</originalMultiAttachEnabled>
+            <originalMultiAttachEnabled>{{ volume_modification.original_multi_attach_enabled|lower }}</originalMultiAttachEnabled>
         {% endif %}
         <progress>0</progress>
         <startTime>{{ volume_modification.start_time }}</startTime>
@@ -510,7 +509,7 @@ MODIFY_VOLUME_RESPONSE = """<?xml version="1.0" encoding="UTF-8"?>
             <targetThroughput>{{ volume_modification.target_throughput }}</targetThroughput>
         {% endif %}
         {% if volume_modification.target_multi_attach_enabled %}
-            <targetMultiAttachEnabled>{{ volume_modification.target_multi_attach_enabled }}</targetMultiAttachEnabled>
+            <targetMultiAttachEnabled>{{ volume_modification.target_multi_attach_enabled|lower }}</targetMultiAttachEnabled>
         {% endif %}
         <volumeId>{{ volume.id }}</volumeId>
     </volumeModification>
@@ -538,7 +537,7 @@ DESCRIBE_VOLUMES_MODIFICATIONS_RESPONSE = """
                 <originalThroughput>{{ modification.original_throughput }}</originalThroughput>
             {% endif %}
             {% if modification.original_multi_attach_enabled %}
-                <originalMultiAttachEnabled>{{ modification.original_multi_attach_enabled }}</originalMultiAttachEnabled>
+                <originalMultiAttachEnabled>{{ modification.original_multi_attach_enabled|lower }}</originalMultiAttachEnabled>
             {% endif %}
             <progress>100</progress>
             <startTime>{{ modification.start_time }}</startTime>
@@ -555,7 +554,7 @@ DESCRIBE_VOLUMES_MODIFICATIONS_RESPONSE = """
                 <targetThroughput>{{ modification.target_throughput }}</targetThroughput>
             {% endif %}
             {% if modification.target_multi_attach_enabled %}
-                <targetMultiAttachEnabled>{{ modification.target_multi_attach_enabled }}</targetMultiAttachEnabled>
+                <targetMultiAttachEnabled>{{ modification.target_multi_attach_enabled|lower }}</targetMultiAttachEnabled>
             {% endif %}
             <volumeId>{{ modification.volume.id }}</volumeId>
         </item>
