@@ -4,7 +4,7 @@ import re
 from collections import defaultdict
 from datetime import datetime, timezone
 from ipaddress import IPv4Address, ip_address, ip_network
-from typing import Any, Dict, List, Optional, Set
+from typing import Any, Optional
 
 from moto.core.base_backend import BackendDict, BaseBackend
 from moto.core.common_models import BaseModel
@@ -62,7 +62,7 @@ class ResolverRuleAssociation(BaseModel):
         self.status = "COMPLETE"
         self.status_message = ""
 
-    def description(self) -> Dict[str, Any]:
+    def description(self) -> dict[str, Any]:
         """Return dictionary of relevant info for resolver rule association."""
         return {
             "Id": self.id,
@@ -99,7 +99,7 @@ class ResolverRule(BaseModel):
         creator_request_id: str,
         rule_type: str,
         domain_name: str,
-        target_ips: Optional[List[Dict[str, Any]]],
+        target_ips: Optional[list[dict[str, Any]]],
         resolver_endpoint_id: Optional[str],
         name: str,
     ):
@@ -132,7 +132,7 @@ class ResolverRule(BaseModel):
     def arn(self) -> str:
         return f"arn:{get_partition(self.region)}:route53resolver:{self.region}:{self.account_id}:resolver-rule/{self.id}"
 
-    def description(self) -> Dict[str, Any]:
+    def description(self) -> dict[str, Any]:
         """Return a dictionary of relevant info for this resolver rule."""
         return {
             "Id": self.id,
@@ -176,9 +176,9 @@ class ResolverEndpoint(BaseModel):
         region: str,
         endpoint_id: str,
         creator_request_id: str,
-        security_group_ids: List[str],
+        security_group_ids: list[str],
         direction: str,
-        ip_addresses: List[Dict[str, Any]],
+        ip_addresses: list[dict[str, Any]],
         name: str,
     ):
         self.account_id = account_id
@@ -226,19 +226,19 @@ class ResolverEndpoint(BaseModel):
         subnet_info = self.ec2_backend.describe_subnets(subnet_ids=[first_subnet_id])[0]
         return subnet_info.vpc_id
 
-    def _build_subnet_info(self) -> Dict[str, Any]:
+    def _build_subnet_info(self) -> dict[str, Any]:
         """Create a dict of subnet info, including ip addrs and ENI ids.
 
         self.subnets[subnet_id][ip_addr1] = eni-id1 ...
         """
-        subnets: Dict[str, Any] = defaultdict(dict)
+        subnets: dict[str, Any] = defaultdict(dict)
         for entry in self.ip_addresses:
             subnets[entry["SubnetId"]][entry["Ip"]] = (
                 f"rni-{mock_random.get_random_hex(17)}"
             )
         return subnets
 
-    def create_eni(self) -> List[str]:
+    def create_eni(self) -> list[str]:
         """Create a VPC ENI for each combo of AZ, subnet and IP."""
         eni_ids = []
         for subnet, ip_info in self.subnets.items():
@@ -261,7 +261,7 @@ class ResolverEndpoint(BaseModel):
         for eni_id in self.eni_ids:
             self.ec2_backend.delete_network_interface(eni_id)
 
-    def description(self) -> Dict[str, Any]:
+    def description(self) -> dict[str, Any]:
         """Return a dictionary of relevant info for this resolver endpoint."""
         return {
             "Id": self.id,
@@ -278,7 +278,7 @@ class ResolverEndpoint(BaseModel):
             "ModificationTime": self.modification_time,
         }
 
-    def ip_descriptions(self) -> List[Dict[str, str]]:
+    def ip_descriptions(self) -> list[dict[str, str]]:
         """Return a list of dicts describing resolver endpoint IP addresses."""
         description = []
         for subnet_id, ip_info in self.subnets.items():
@@ -301,7 +301,7 @@ class ResolverEndpoint(BaseModel):
         self.name = name
         self.modification_time = datetime.now(timezone.utc).isoformat()
 
-    def associate_ip_address(self, value: Dict[str, Any]) -> None:
+    def associate_ip_address(self, value: dict[str, Any]) -> None:
         self.ip_addresses.append(value)
         self.ip_address_count = len(self.ip_addresses)
 
@@ -320,7 +320,7 @@ class ResolverEndpoint(BaseModel):
         )
         self.eni_ids.append(eni_info.id)
 
-    def disassociate_ip_address(self, value: Dict[str, Any]) -> None:
+    def disassociate_ip_address(self, value: dict[str, Any]) -> None:
         if not value.get("Ip") and value.get("IpId"):
             for ip_addr, eni_id in self.subnets[value.get("SubnetId")].items():  # type: ignore
                 if value.get("IpId") == eni_id:
@@ -373,7 +373,7 @@ class ResolverQueryLogConfig(BaseModel):
     def arn(self) -> str:
         return f"arn:{get_partition(self.region)}:route53resolver:{self.region}:{self.account_id}:resolver-query-log-config/{self.id}"
 
-    def description(self) -> Dict[str, Any]:
+    def description(self) -> dict[str, Any]:
         """Return a dictionary of relevant info for this query log config."""
         return {
             "Id": self.id,
@@ -409,7 +409,7 @@ class ResolverQueryLogConfigAssociation(BaseModel):
         self.error_message = ""
         self.creation_time = datetime.now(timezone.utc).isoformat()
 
-    def description(self) -> Dict[str, Any]:
+    def description(self) -> dict[str, Any]:
         """Return a dictionary of relevant info for this query log config association."""
         return {
             "Id": self.id,
@@ -427,19 +427,19 @@ class Route53ResolverBackend(BaseBackend):
 
     def __init__(self, region_name: str, account_id: str):
         super().__init__(region_name, account_id)
-        self.resolver_endpoints: Dict[
+        self.resolver_endpoints: dict[
             str, ResolverEndpoint
         ] = {}  # Key is self-generated ID (endpoint_id)
-        self.resolver_rules: Dict[
+        self.resolver_rules: dict[
             str, ResolverRule
         ] = {}  # Key is self-generated ID (rule_id)
-        self.resolver_rule_associations: Dict[
+        self.resolver_rule_associations: dict[
             str, ResolverRuleAssociation
         ] = {}  # Key is resolver_rule_association_id)
-        self.resolver_query_log_configs: Dict[
+        self.resolver_query_log_configs: dict[
             str, ResolverQueryLogConfig
         ] = {}  # Key is resolver_query_log_config_id
-        self.resolver_query_log_config_associations: Dict[
+        self.resolver_query_log_config_associations: dict[
             str, ResolverQueryLogConfigAssociation
         ] = {}  # Key is resolver_query_log_config_association_id
         self.tagger = TaggingService()
@@ -448,8 +448,8 @@ class Route53ResolverBackend(BaseBackend):
 
     @staticmethod
     def default_vpc_endpoint_service(
-        service_region: str, zones: List[str]
-    ) -> List[Dict[str, str]]:
+        service_region: str, zones: list[str]
+    ) -> list[dict[str, str]]:
         """List of dicts representing default VPC endpoints for this service."""
         return BaseBackend.default_vpc_endpoint_service_factory(
             service_region, zones, "route53resolver"
@@ -501,7 +501,7 @@ class Route53ResolverBackend(BaseBackend):
         return rule_association
 
     def _verify_subnet_ips(
-        self, ip_addresses: List[Dict[str, Any]], initial: bool = True
+        self, ip_addresses: list[dict[str, Any]], initial: bool = True
     ) -> None:
         """
         Perform additional checks on the IPAddresses.
@@ -515,7 +515,7 @@ class Route53ResolverBackend(BaseBackend):
                     "Resolver endpoint needs to have at least 2 IP addresses"
                 )
 
-        subnets: Dict[str, Set[str]] = defaultdict(set)
+        subnets: dict[str, set[str]] = defaultdict(set)
         for subnet_id, ip_addr in [(x["SubnetId"], x["Ip"]) for x in ip_addresses]:
             try:
                 subnet_info = self.ec2_backend.describe_subnets(subnet_ids=[subnet_id])[
@@ -541,7 +541,7 @@ class Route53ResolverBackend(BaseBackend):
                 )
             subnets[subnet_id].add(ip_addr)
 
-    def _verify_security_group_ids(self, security_group_ids: List[str]) -> None:
+    def _verify_security_group_ids(self, security_group_ids: list[str]) -> None:
         """Perform additional checks on the security groups."""
         if len(security_group_ids) > 10:
             raise InvalidParameterException("Maximum of 10 security groups are allowed")
@@ -564,10 +564,10 @@ class Route53ResolverBackend(BaseBackend):
         region: str,
         creator_request_id: str,
         name: str,
-        security_group_ids: List[str],
+        security_group_ids: list[str],
         direction: str,
-        ip_addresses: List[Dict[str, Any]],
-        tags: List[Dict[str, str]],
+        ip_addresses: list[dict[str, Any]],
+        tags: list[dict[str, str]],
     ) -> ResolverEndpoint:
         """
         Return description for a newly created resolver endpoint.
@@ -637,9 +637,9 @@ class Route53ResolverBackend(BaseBackend):
         name: str,
         rule_type: str,
         domain_name: str,
-        target_ips: List[Dict[str, Any]],
+        target_ips: list[dict[str, Any]],
         resolver_endpoint_id: str,
-        tags: List[Dict[str, str]],
+        tags: list[dict[str, str]],
     ) -> ResolverRule:
         """Return description for a newly created resolver rule."""
         validate_args(
@@ -841,13 +841,13 @@ class Route53ResolverBackend(BaseBackend):
     @paginate(pagination_model=PAGINATION_MODEL)  # type: ignore[misc]
     def list_resolver_endpoint_ip_addresses(
         self, resolver_endpoint_id: str
-    ) -> List[Dict[str, str]]:
+    ) -> list[dict[str, str]]:
         self._validate_resolver_endpoint_id(resolver_endpoint_id)
         endpoint = self.resolver_endpoints[resolver_endpoint_id]
         return endpoint.ip_descriptions()
 
     @staticmethod
-    def _add_field_name_to_filter(filters: List[Dict[str, Any]]) -> None:  # type: ignore[misc]
+    def _add_field_name_to_filter(filters: list[dict[str, Any]]) -> None:  # type: ignore[misc]
         """Convert both styles of filter names to lowercase snake format.
 
         "IP_ADDRESS_COUNT" or "IpAddressCount" will become "ip_address_count".
@@ -870,7 +870,7 @@ class Route53ResolverBackend(BaseBackend):
             rr_filter["Field"] = filter_name.lower()
 
     @staticmethod
-    def _validate_filters(filters: Any, allowed_filter_names: List[str]) -> None:  # type: ignore[misc]
+    def _validate_filters(filters: Any, allowed_filter_names: list[str]) -> None:  # type: ignore[misc]
         """Raise exception if filter names are not as expected."""
         for rr_filter in filters:
             if rr_filter["Field"] not in allowed_filter_names:
@@ -900,7 +900,7 @@ class Route53ResolverBackend(BaseBackend):
         return True
 
     @paginate(pagination_model=PAGINATION_MODEL)
-    def list_resolver_endpoints(self, filters: Any) -> List[ResolverEndpoint]:
+    def list_resolver_endpoints(self, filters: Any) -> list[ResolverEndpoint]:
         if not filters:
             filters = []
 
@@ -914,7 +914,7 @@ class Route53ResolverBackend(BaseBackend):
         return endpoints
 
     @paginate(pagination_model=PAGINATION_MODEL)
-    def list_resolver_rules(self, filters: Any) -> List[ResolverRule]:
+    def list_resolver_rules(self, filters: Any) -> list[ResolverRule]:
         if not filters:
             filters = []
 
@@ -930,7 +930,7 @@ class Route53ResolverBackend(BaseBackend):
     @paginate(pagination_model=PAGINATION_MODEL)
     def list_resolver_rule_associations(
         self, filters: Any
-    ) -> List[ResolverRuleAssociation]:
+    ) -> list[ResolverRuleAssociation]:
         if not filters:
             filters = []
 
@@ -958,11 +958,11 @@ class Route53ResolverBackend(BaseBackend):
         )
 
     @paginate(pagination_model=PAGINATION_MODEL)
-    def list_tags_for_resource(self, resource_arn: str) -> List[Dict[str, str]]:
+    def list_tags_for_resource(self, resource_arn: str) -> list[dict[str, str]]:
         self._matched_arn(resource_arn)
         return self.tagger.list_tags_for_resource(resource_arn)["Tags"]
 
-    def tag_resource(self, resource_arn: str, tags: List[Dict[str, str]]) -> None:
+    def tag_resource(self, resource_arn: str, tags: list[dict[str, str]]) -> None:
         self._matched_arn(resource_arn)
         errmsg = self.tagger.validate_tags(
             tags, limit=ResolverEndpoint.MAX_TAGS_PER_RESOLVER_ENDPOINT
@@ -971,7 +971,7 @@ class Route53ResolverBackend(BaseBackend):
             raise TagValidationException(errmsg)
         self.tagger.tag_resource(resource_arn, tags)
 
-    def untag_resource(self, resource_arn: str, tag_keys: List[str]) -> None:
+    def untag_resource(self, resource_arn: str, tag_keys: list[str]) -> None:
         self._matched_arn(resource_arn)
         self.tagger.untag_resource_using_names(resource_arn, tag_keys)
 
@@ -985,7 +985,7 @@ class Route53ResolverBackend(BaseBackend):
         return resolver_endpoint
 
     def associate_resolver_endpoint_ip_address(
-        self, resolver_endpoint_id: str, value: Dict[str, Any]
+        self, resolver_endpoint_id: str, value: dict[str, Any]
     ) -> ResolverEndpoint:
         self._validate_resolver_endpoint_id(resolver_endpoint_id)
         resolver_endpoint = self.resolver_endpoints[resolver_endpoint_id]
@@ -1001,7 +1001,7 @@ class Route53ResolverBackend(BaseBackend):
         return resolver_endpoint
 
     def disassociate_resolver_endpoint_ip_address(
-        self, resolver_endpoint_id: str, value: Dict[str, Any]
+        self, resolver_endpoint_id: str, value: dict[str, Any]
     ) -> ResolverEndpoint:
         self._validate_resolver_endpoint_id(resolver_endpoint_id)
         resolver_endpoint = self.resolver_endpoints[resolver_endpoint_id]
@@ -1019,7 +1019,7 @@ class Route53ResolverBackend(BaseBackend):
         name: str,
         destination_arn: str,
         creator_request_id: str,
-        tags: Optional[List[Dict[str, str]]] = None,
+        tags: Optional[list[dict[str, str]]] = None,
     ) -> ResolverQueryLogConfig:
         if tags:
             errmsg = self.tagger.validate_tags(
